psychopy_ext.exp.default_computer — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.default_computer

class `psychopy_ext.exp.` `default_computer`

  The default computer parameters. Hopefully will form a full class at some point.

  `__init__`()

  Methods

  `__init__`() |

  Attributes

  `default_keys` | dict() -> new empty dictionary
  `distance` | int(x=0) -> int or long
  `name` | str(object=’‘) -> string
  `recognized` | bool(x) -> bool
  `root` | str(object=’‘) -> string
  `screen` | int(x=0) -> int or long
  `stereo` | bool(x) -> bool
  `valid_responses` | dict() -> new empty dictionary
  `view_scale` | list() -> new empty list
  `width` | float(x) -> floating point number